==> owncloud-8.1.9.tar.bz2: owncloud/apps/files_antivirus/l10n/it.js <==
OC.L10N.register(
    "files_antivirus",
    {
    "Saved" : "Salvato",
    "Clean" : "Pulisci",
    "Infected" : "Infetto",
    "Unchecked" : "Non marcato",
    "Scanner exit status" : "Stato di uscita dell'analizzatore",
    "Scanner output" : "Risultato analisi",
    "Saving..." : "Salvataggio in corso...",
    "<strong>Infected file</strong> has been <strong>found</strong>" : "Un <strong>file infetto</strong> è stato <strong>trovato</strong>",
    "File %s is infected with %s" : "Il file %s è infetto da %s",
    "It is going to be deleted" : "Sta per essere eliminato",
    "Antivirus" : "Antivirus",
    "Virus detected! Can't upload the file %s" : "Virus rilevato! Impossibile caricare il file %s",
    "Malware detected" : "Malware rilevato",
    "Greetings {user}," : "Ciao {user},",
    "Sorry, but a malware was detected in a file you tried to upload and it had to be deleted." : "Siamo spiacenti, ma un malware è stato rilevato in un file che hai provato a caricare ed è necessario eliminarlo.",
    "This email is a notification from {host}. Please, do not reply." : "Questa email è una notifica proveniente da {host}. Per favore non rispondere.",
    "File uploaded: {file}" : "File caricato: {file}",
    "Antivirus Configuration" : "Configurazione antivirus",
    "Mode" : "Modalità",
    "Executable" : "Eseguibile",
    "Daemon" : "Demone",
    "Daemon (Socket)" : "Demone (Socket)",
    "Socket" : "Socket",
    "Clamav Socket." : "Socket di Clamav.",
    "Not required in Executable Mode." : "Non richiesto in modalità eseguibile.",
    "Host" : "Host",
    "Address of Antivirus Host." : "Indirizzo IP Host Antivirus",
    "Port" : "Porta",
    "Port number of Antivirus Host." : "Numero di Porta Host Antivirus",
    "Stream Length" : "Lunghezza Stream",
    "ClamAV StreamMaxLength value in bytes." : "ClamAV StreamMaxLength valore in bytes.",
    "Path to clamscan" : "Percorso a clamscan",
    "Path to clamscan executable." : "Percorso all'eseguibile di clamscan",
    "Not required in Daemon Mode." : "Non richiesto in modalità demone.",
    "Extra command line options (comma-separated)" : "Opzioni aggiuntive da riga di comando (separate da virgole)",
    "Action for infected files found while scanning" : "Azione per i file infetti trovati durante la scansione",
    "Only log" : "Solo log",
    "Delete file" : "Elimina il file",
    "Save" : "Salva",
    "Advanced" : "Avanzate",
    "Rules" : "Regole",
    "Clear All" : "Pulisci tutto",
    "Reset to defaults" : "Ripristina i valori predefiniti",
    "Match by" : "Verificato da",
    "Scanner exit status or signature to search" : "Stato di uscita dell'analizzatore o firma da cercare",
    "Description" : "Descrizione",
    "Mark as" : "Marca come",
    "Add a rule" : "Aggiungi una regola"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.16.0.tar.bz2: owncloud/apps/files_antivirus/l10n/it.js <==
OC.L10N.register(
    "files_antivirus",
    {
    "Clean" : "Pulito",
    "Infected" : "Infetto",
    "Unchecked" : "Non marcato",
    "Scanner exit status" : "Stato di uscita dell'analizzatore",
    "Scanner output" : "Risultato analisi",
    "Saving..." : "Salvataggio in corso...",
    "Test scan was unsuccessful. Please recheck antivirus settings." : "Scansione non eseguita. Ricontrolla la configurazione dell'antivirus",
    "<strong>Infected file</strong> has been <strong>found</strong>" : "Un <strong>file infetto</strong> è stato <strong>trovato</strong>",
    "File %s is infected with %s" : "Il file %s è infetto da %s",
    "It is going to be deleted" : "Sta per essere eliminato",
    "Antivirus" : "Antivirus",
    "Virus %s is detected in the file. Upload cannot be completed." : "Il virus %s è stato rilevato nel file. Il caricamento non può essere completato.",
    "Saved" : "Salvato",
    "Virus detected! Can't upload the file %s" : "Virus rilevato! Impossibile caricare il file %s",
    "Malware detected" : "Malware rilevato",
    "Greetings {user}," : "Ciao {user},",
    "This email is a notification from {host}. Please, do not reply." : "Questa email è una notifica proveniente da {host}. Per favore non rispondere.",
    "File uploaded: {file}" : "File caricato: {file}",
    "Antivirus Configuration" : "Configurazione antivirus",
    "Mode" : "Modalità",
    "Executable" : "Eseguibile",
    "Socket" : "Socket",
    "Clamav Socket" : "Socket Clamav",
    "Host" : "Host",
    "Hostname or IP address of Antivirus Host" : "Nome host o indirizzo IP del server Antivirus",
    "Port" : "Porta",
    "Port number of Antivirus Host, 1-65535" : "Numero porta del server Antivirus, 1-65535",
    "Path to clamscan" : "Percorso a clamscan",
    "Extra command line options (comma-separated)" : "Opzioni aggiuntive da riga di comando (separate da virgole)",
    "Stream Length" : "Lunghezza Stream",
    "ClamAV StreamMaxLength value in bytes" : "Valore di ClamAV SteamMaxLengh in bytes",
    "bytes" : "byte",
    "File size limit, -1 means no limit" : "Limite di dimensione del file, -1 significa nessun limite",
    "File size limit in bytes, -1 means no limit" : "Limite di dimensione del file in byte, -1 significa nessun limite",
    "Enabled" : "Abilitata",
    "Disabled" : "Disabilitato",
    "When infected files were found during a background scan" : "Quando file infetti sono stati trovati durante una scansione in background",
    "Only log" : "Solo log",
    "Delete file" : "Elimina il file",
    "Save" : "Salva",
    "Advanced" : "Avanzate",
    "Rules" : "Regole",
    "Clear All" : "Pulisci tutto",
    "Reset to defaults" : "Ripristina i valori predefiniti",
    "Match by" : "Verificato da",
    "Scanner exit status or signature to search" : "Stato di uscita dell'analizzatore o firma da cercare",
    "Description" : "Descrizione",
    "Mark as" : "Marca come",
    "Add a rule" : "Aggiungi una regola"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
